@@ -117,7 +117,7 @@ class Tags:
 class Send_Form:
     def __init__(self, url):
         try:
-            self.src = requests.get(url).text
+            self.src = requests.get(url, allow_redirects=True, verify=False).text
         except requests.exceptions.InvalidSchema:
             raise requests.exceptions.InvalidSchema("")
         self.method = None
@@ -170,9 +170,9 @@ class Send_Form:
                     msg = msg[:-1]
 
                 url = f"{self.url}{msg}"
-                self.src = requests.get(url).text
+                self.src = requests.get(url, allow_redirects=True, verify=False).text
             elif self.method.lower() == "post":
-                self.src = requests.post(self.url, data=self.data).text
+                self.src = requests.post(self.url, data=self.data, allow_redirects=True, verify=False).text
 
     def change(self, param_name=None, new_value=None):
         self.get_tags()
